@@ -2,19 +2,18 @@ package Tatsumaki::Template::Micro;
 use Moose;
 extends 'Tatsumaki::Template';
 
-use Text::MicroTemplate::Extended;
-has mt => (is => 'rw', isa => 'Text::MicroTemplate::Extended', handles => [ 'render_file' ]);
+use Text::MicroTemplate::File;
+has mt => (is => 'rw', isa => 'Text::MicroTemplate::File', handles => [ 'render_file' ]);
 
 sub BUILD {
     my $self = shift;
 
-    my $mt = Text::MicroTemplate::Extended->new(
+    my $mt = Text::MicroTemplate::File->new(
         include_path => [ 'templates' ],
         use_cache => 0,
         tag_start => '<%',
         tag_end   => '%>',
         line_start => '%',
-        extension => '',
     );
 
     $self->mt($mt);
